@@ -3,7 +3,7 @@ use 5.008;
 use warnings;
 use strict;
 
-our $VERSION = '1.67';
+our $VERSION = '1.68';
 
 use Carp;
 use Data::Compare;
@@ -739,6 +739,8 @@ sub _read_file {
             or confess "DES::_read_file() can't create backup copy $bak!";
     }
 
+    die "Can't call method \"serialize\" on an undefined file\n" if ! -f $file;
+
     $self->{rw} = File::Edit::Portable->new;
 
     my $ppi_doc;
@@ -764,7 +766,7 @@ sub _read_file {
         $ppi_doc = PPI::Document->new($file);
     }
 
-    @{ $p->{file_contents} } = split /\n/, $ppi_doc->content;
+    @{ $p->{file_contents} } = split /\n/, $ppi_doc->serialize;
 
 
     if (! $p->{file_contents}->[0]){
@@ -1254,10 +1256,17 @@ Perl files and subs.
 
     use Devel::Examine::Subs;
 
-    my $file = 'perl.pl'; # or directory, or Module::Name
-    my $search = 'string';
+    # examine a file
 
-    my $des = Devel::Examine::Subs->new( file => $file );
+    my $des = Devel::Examine::Subs->new( file => 'perl.pl' );
+
+    # examine all the Perl files in a directory
+
+    my $des = Devel::Examine::Subs->new( file => '/path/to/directory' );
+
+    # load a module by name. Uses %INC to find the path after loading it
+
+    my $des = Devel::Examine::Subs->new( file => 'Some::Module::Name' );
 
 
 Get all sub names in a file
@@ -1297,6 +1306,7 @@ Get the sub objects within a hash
 
 Get all subs containing "string" in the body
 
+    my $search = 'string';
     my $aref = $des->has( search => $search );
 
 Search and replace code in subs
@@ -1371,13 +1381,14 @@ Most methods can include or exclude specific subs
 Gather information about subroutines in Perl files (and in-memory modules),
 with the ability to search/replace code, inject new code, get line counts,
 get start and end line numbers, access the sub's code and a myriad of other
-options.
+options.  Files are parsed using L<PPI>, not by inspecting packages or
+coderefs.
 
 
 
 =head1 METHODS
 
-See the L<PARAMETERS> for the full list of params, and which ones
+See the L</PARAMETERS> for the full list of params, and which ones
 are persistent across runs using the same object.
 
 
@@ -1456,7 +1467,7 @@ C<objects_in_hash> is sent in with a true value, the objects will be returned
 in a hash reference where the key is the sub's name, and the value is the sub
 object.
 
-See L<SYNOPSIS> for the structure of each object.
+See L</SYNOPSIS> for the structure of each object.
 
 
 
@@ -1531,12 +1542,12 @@ the search term is used for any new code injected. Set C<no_indent> parameter
 to a true value to disable this feature.
 
 By default, an injection only happens after the first time a search term is
-found. Use the C<injects> parameter (see L<PARAMETERS>) to change this
+found. Use the C<injects> parameter (see L</PARAMETERS>) to change this
 behaviour. Setting to a positive integer beyond 1 will inject after that many
 finds. Set to a negative integer will inject after all finds.
 
 The C<code> array should contain one line of code (or blank line) per each
-element. (See L<SYNOPSIS> for an example). The code is not manipulated prior
+element. (See L</SYNOPSIS> for an example). The code is not manipulated prior
 to injection, it is inserted exactly as typed. Best to use a heredoc,
 C<__DATA__> section or an external text file for the code.
 
@@ -1554,7 +1565,7 @@ See C<search_replace()> for a description of how this parameter is used.
 
 =item C<injects>
 
-How many injections do you want to do per sub? See L<PARAMETERS> for more
+How many injections do you want to do per sub? See L</PARAMETERS> for more
 details.
 
 =back
